@@ -6,7 +6,7 @@
  *
  * @author      t.shirayanagi
  * @par         copyright
- * Copyright (C) 2011-2017, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2018, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -692,6 +692,17 @@
 #  define IUTEST_HAS_NOEXCEPT   0
 #endif
 
+//! noexcept function type
+#if !defined(IUTEST_HAS_NOEXCEPT_FUNCTION_TYPE)
+#  if defined(__cpp_noexcept_function_type) && __cpp_noexcept_function_type >= 201510L
+#    define IUTEST_HAS_NOEXCEPT_FUNCTION_TYPE 1
+#  endif
+#endif
+
+#if !defined(IUTEST_HAS_NOEXCEPT_FUNCTION_TYPE)
+#  define IUTEST_HAS_NOEXCEPT_FUNCTION_TYPE 0
+#endif
+
 //! noexcept definition
 #if !defined(IUTEST_CXX_NOEXCEPT)
 #  if IUTEST_HAS_NOEXCEPT
@@ -907,6 +918,13 @@
 #  endif
 #endif
 
+//! has fileno
+#if !defined(IUTEST_HAS_FILENO)
+#  if !defined(IUTEST_OS_WINDOWS_MOBILE) && !defined(__STRICT_ANSI__)
+#    define IUTEST_HAS_FILENO               1
+#  endif
+#endif
+
 //! explicit class member template specialization
 #if !defined(IUTEST_HAS_CLASS_MEMBER_TEMPLATE_SPECIALIZATION)
 #  if defined(_MSC_VER)
@@ -1206,6 +1224,33 @@
 #  define IUTEST_ATTRIBUTE_INIT_PRIORITY_(n)
 #endif
 
+//! MemorySanitizer
+#if !defined(IUTEST_HAS_MEMORY_SANITIZER)
+#  if defined(__has_feature)
+#    if __has_feature(memory_sanitizer)
+#      define IUTEST_HAS_MEMORY_SANITIZER   1
+#    endif
+#  endif
+#endif
+
+#if !defined(IUTEST_HAS_MEMORY_SANITIZER)
+#  define IUTEST_HAS_MEMORY_SANITIZER       0
+#endif
+
+#if !defined(IUTEST_ATTRIBUTE_NO_SANITIZE_MEMORY)
+#  if IUTEST_HAS_MEMORY_SANITIZER
+#    if   defined(__clang__)
+#      define IUTEST_ATTRIBUTE_NO_SANITIZE_MEMORY   __attribute__((no_sanitize("memory")))
+#    elif defined(__GNUC__) && !defined(COMPILER_ICC)
+#      define IUTEST_ATTRIBUTE_NO_SANITIZE_MEMORY   __attribute__((no_sanitize("memory")))
+#    endif
+#  endif
+#endif
+
+#if !defined(IUTEST_ATTRIBUTE_NO_SANITIZE_MEMORY)
+#  define IUTEST_ATTRIBUTE_NO_SANITIZE_MEMORY
+#endif
+
 
 // workaround
 /**
