@@ -6,7 +6,7 @@
  *
  * @author      t.shirayanagi
  * @par         copyright
- * Copyright (C) 2012-2016, Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2018, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -93,20 +93,20 @@
 #endif
 
 #if   defined(__clang__)
-#  define IUTEST_PARGMA_WARN_PUSH()     IUTEST_PRAGMA_CLANG_WARN_PUSH()
-#  define IUTEST_PARGMA_WARN_POP()      IUTEST_PRAGMA_CLANG_WARN_PUSH()
+#  define IUTEST_PRAGMA_WARN_PUSH()     IUTEST_PRAGMA_CLANG_WARN_PUSH()
+#  define IUTEST_PRAGMA_WARN_POP()      IUTEST_PRAGMA_CLANG_WARN_PUSH()
 #  define IUTEST_PRAGMA_WARN_DISABLE(x) IUTEST_PRAGMA_CLANG_WARN_DISABLE(x)
 #elif defined(__GNUC__)
-#  define IUTEST_PARGMA_WARN_PUSH()     IUTEST_PRAGMA_GCC_WARN_PUSH()
-#  define IUTEST_PARGMA_WARN_POP()      IUTEST_PRAGMA_GCC_WARN_POP()
+#  define IUTEST_PRAGMA_WARN_PUSH()     IUTEST_PRAGMA_GCC_WARN_PUSH()
+#  define IUTEST_PRAGMA_WARN_POP()      IUTEST_PRAGMA_GCC_WARN_POP()
 #  define IUTEST_PRAGMA_WARN_DISABLE(x) IUTEST_PRAGMA_GCC_WARN_DISABLE(x)
 #elif defined(_MSC_VER)
-#  define IUTEST_PARGMA_WARN_PUSH()     IUTEST_PRAGMA_MSC_WARN_PUSH()
-#  define IUTEST_PARGMA_WARN_POP()      IUTEST_PRAGMA_MSC_WARN_POP()
+#  define IUTEST_PRAGMA_WARN_PUSH()     IUTEST_PRAGMA_MSC_WARN_PUSH()
+#  define IUTEST_PRAGMA_WARN_POP()      IUTEST_PRAGMA_MSC_WARN_POP()
 #  define IUTEST_PRAGMA_WARN_DISABLE(x)
 #else
-#  define IUTEST_PARGMA_WARN_PUSH()
-#  define IUTEST_PARGMA_WARN_POP()
+#  define IUTEST_PRAGMA_WARN_PUSH()
+#  define IUTEST_PRAGMA_WARN_POP()
 #  define IUTEST_PRAGMA_WARN_DISABLE(x)
 #endif
 
@@ -129,11 +129,22 @@
 
 #if defined(__clang__) || defined(__GNUC__)
 #  define IUTEST_PRAGMA_UNUSED_LOCAL_TYPEDEFS_WARN_DISABLE_BEGIN()  \
-        IUTEST_PARGMA_WARN_PUSH()                                   \
+        IUTEST_PRAGMA_WARN_PUSH()                                   \
         IUTEST_PRAGMA_WARN_DISABLE("-Wunused-local-typedefs")
 #  define IUTEST_PRAGMA_UNUSED_LOCAL_TYPEDEFS_WARN_DISABLE_END()    \
-        IUTEST_PARGMA_WARN_POP()
+        IUTEST_PRAGMA_WARN_POP()
 #else
+#  define IUTEST_PRAGMA_UNUSED_LOCAL_TYPEDEFS_WARN_DISABLE_BEGIN()
+#  define IUTEST_PRAGMA_UNUSED_LOCAL_TYPEDEFS_WARN_DISABLE_END()
+#endif
+
+#if defined(_MSC_VER)
+#  define IUTEST_PRAGMA_UNREACHCODE_WARN_DISABLE_BEGIN()    IUTEST_PRAGMA_MSC_WARN_PUSH()   \
+                                                            IUTEST_PRAGMA_MSC_WARN_DISABLE(4702)
+#  define IUTEST_PRAGMA_UNREACHCODE_WARN_DISABLE_END()      IUTEST_PRAGMA_MSC_WARN_POP()
+#else
+#  define IUTEST_PRAGMA_UNREACHCODE_WARN_DISABLE_BEGIN()
+#  define IUTEST_PRAGMA_UNREACHCODE_WARN_DISABLE_END()
 #endif
 
 #if defined(_MSC_VER) && _MSC_VER < 1700
@@ -191,4 +202,14 @@
 #  define IUTEST_PRAGMA_WARN_DISABLE_DANGLING_ELSE()
 #endif
 
+#if defined(__GNUC__)
+#  if (__GNUC__ > 6)
+#    define IUTEST_PRAGMA_WARN_DISABLE_NOEXCEPT_TPYE()  IUTEST_PRAGMA_GCC_WARN_DISABLE("-Wnoexcept-type")
+#  endif
+#endif
+
+#if !defined(IUTEST_PRAGMA_WARN_DISABLE_NOEXCEPT_TPYE)
+#  define IUTEST_PRAGMA_WARN_DISABLE_NOEXCEPT_TPYE()
+#endif
+
 #endif // INCG_IRIS_IUTEST_PRAGMA_HPP_FBC5A1DE_3D0C_443E_84B1_5F0618DF9A6B_
