@@ -6,7 +6,7 @@
  *
  * @author      t.shirayanagi
  * @par         copyright
- * Copyright (C) 2011-2017, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2018, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -17,11 +17,11 @@
 
 //======================================================================
 // define
-#define IUTEST_VER          0x01160123u //!< iutest version 1.16.1.23
+#define IUTEST_VER          0x01160300u //!< iutest version 1.16.3.0
 #define IUTEST_MAJORVER     0x01u       //!< Major Version
 #define IUTEST_MINORVER     0x16u       //!< Minor Version
-#define IUTEST_MICROVER     0x01u       //!< Micro Version
-#define IUTEST_REVISION     0x23u       //!< Revision
+#define IUTEST_MICROVER     0x03u       //!< Micro Version
+#define IUTEST_REVISION     0x00u       //!< Revision
 
 #define IUTEST_BUILD        IUTEST_MICROVER //!< @deprecated
 
@@ -33,7 +33,7 @@
  *          google group: https://groups.google.com/forum/?fromgroups#!forum/g-iutest \n
  *
  * @par     copyright
- * Copyright (C) 2011-2017, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2018, Takazumi Shirayanagi\n
  * This software is released under the new BSD License.
  *
  * @par     LICENSE
@@ -120,6 +120,11 @@
  * @page    CHANGELOG   変更履歴
  * @par     Changes
  <ul>
+  <li>v1.16.3.0
+    <ul>
+      <li>IUTEST_ASSERT,IUTEST_EXPECT の Variadic 対応</li>
+    </ul>
+  </li>
   <li>v1.16.2.0
     <ul>
       <li>警告をエラーとするオプション(--iutest_warning_into_error)を追加</li>
