@@ -36,10 +36,11 @@ int SetUpEnvironmentImpl(void)
     if( ::iutest::internal::posix::PutEnv(ENV_PREFIX "REPEAT=2") == -1 ) return -1;
     if( ::iutest::internal::posix::PutEnv(ENV_PREFIX "FILTER=Flag*") == -1 ) return -1;
     if( ::iutest::internal::posix::PutEnv(ENV_PREFIX "OUTPUT=test") == -1 ) return -1;
-    if( ::iutest::internal::posix::PutEnv("XML_OUTPUT_FILE=hoge") == -1 ) return -1; // OUTPUT envrionment takes precedence
+    if( ::iutest::internal::posix::PutEnv("XML_OUTPUT_FILE=hoge") == -1 ) return -1; // OUTPUT environment takes precedence
 
     if( ::iutest::internal::posix::PutEnv("IUTEST_DEFAULT_PACKAGE_NAME=env_var") == -1 ) return -1;
     if( ::iutest::internal::posix::PutEnv("IUTEST_FILE_LOCATION=vs") == -1 ) return -1;
+    if( ::iutest::internal::posix::PutEnv("IUTEST_WARNING_INTO_ERROR=1") == -1 ) return -1;
 
     return 0;
 }
@@ -65,7 +66,7 @@ IUTEST_PRAGMA_CRT_SECURE_WARN_DISABLE_BEGIN()
 
 IUTEST(FlagTest, Check)
 {
-    IUTEST_ASSUME_EQ(0, g_result.setup_environment) << lasterror << ": " << strerror(lasterror);  // putenv に失敗した場合はテストしない
+    IUTEST_ASSUME_EQ(0, g_result.setup_environment) << "\n" << lasterror << ": " << strerror(lasterror);  // putenv に失敗した場合はテストしない
     IUTEST_EXPECT_TRUE( ::iutest::IUTEST_FLAG(also_run_disabled_tests) );
     IUTEST_EXPECT_TRUE( ::iutest::IUTEST_FLAG(break_on_failure) );
     IUTEST_EXPECT_TRUE( ::iutest::IUTEST_FLAG(throw_on_failure) );
@@ -75,6 +76,7 @@ IUTEST(FlagTest, Check)
 #if !defined(IUTEST_USE_GTEST)
     IUTEST_EXPECT_STREQ( "env_var", ::iutest::IUTEST_FLAG(default_package_name).c_str() );
     IUTEST_EXPECT_TRUE( ::iutest::IUTEST_FLAG(file_location_style_msvc) );
+    IUTEST_EXPECT_TRUE( ::iutest::IUTEST_FLAG(warning_into_error) );
 #endif
 
     IUTEST_EXPECT_EQ( 200u, ::iutest::IUTEST_FLAG(random_seed) );
@@ -104,6 +106,16 @@ int main(int argc, char* argv[])
 #endif
     int targc = 1;
     IUTEST_INIT(&targc, targv);
-    return IUTEST_RUN_ALL_TESTS();
+#if !defined(IUTEST_USE_GTEST)
+    if( g_result.setup_environment == 0 && ::iutest::IUTEST_FLAG(warning_into_error) )
+    {
+        if( IUTEST_RUN_ALL_TESTS() == 0 ) return 1;
+    }
+    else
+#endif
+    {
+        if( IUTEST_RUN_ALL_TESTS() != 0 ) return 1;
+    }
+    return 0;
 }
 
