@@ -29,7 +29,6 @@ IUTEST(NoFatalFailureTest, Assert)
 {
     IUTEST_ASSERT_NO_FATAL_FAILURE(;);
     IUTEST_ASSERT_NO_FATAL_FAILURE(IUTEST_SUCCEED());
-    IUTEST_ASSERT_NO_FATAL_FAILURE(IUTEST_SKIP());
     IUTEST_ASSERT_NO_FATAL_FAILURE(NoFatalFailureTest_Subroutine());
     IUTEST_ASSERT_NO_FATAL_FAILURE({ IUTEST_SUCCEED(); });
 }
@@ -38,7 +37,6 @@ IUTEST(NoFatalFailureTest, Expect)
 {
     IUTEST_EXPECT_NO_FATAL_FAILURE(;);
     IUTEST_EXPECT_NO_FATAL_FAILURE(IUTEST_SUCCEED());
-    IUTEST_EXPECT_NO_FATAL_FAILURE(IUTEST_SKIP());
     IUTEST_EXPECT_NO_FATAL_FAILURE(NoFatalFailureTest_Subroutine());
     IUTEST_EXPECT_NO_FATAL_FAILURE({ IUTEST_SUCCEED(); });
 }
@@ -47,7 +45,6 @@ IUTEST(NoFatalFailureTest, Inform)
 {
     IUTEST_INFORM_NO_FATAL_FAILURE(;);
     IUTEST_INFORM_NO_FATAL_FAILURE(IUTEST_SUCCEED());
-    IUTEST_INFORM_NO_FATAL_FAILURE(IUTEST_SKIP());
     IUTEST_INFORM_NO_FATAL_FAILURE(NoFatalFailureTest_Subroutine());
     IUTEST_INFORM_NO_FATAL_FAILURE({ IUTEST_SUCCEED(); });
 }
@@ -56,7 +53,6 @@ IUTEST(NoFatalFailureTest, Assume)
 {
     IUTEST_ASSUME_NO_FATAL_FAILURE(;);
     IUTEST_ASSUME_NO_FATAL_FAILURE(IUTEST_SUCCEED());
-    IUTEST_ASSUME_NO_FATAL_FAILURE(IUTEST_SKIP());
     IUTEST_ASSUME_NO_FATAL_FAILURE(NoFatalFailureTest_Subroutine());
     IUTEST_ASSUME_NO_FATAL_FAILURE({ IUTEST_SUCCEED(); });
 }
@@ -65,7 +61,6 @@ IUTEST(NoFailureTest, Assert)
 {
     IUTEST_ASSERT_NO_FAILURE(;);
     IUTEST_ASSERT_NO_FAILURE(IUTEST_SUCCEED());
-    IUTEST_ASSERT_NO_FAILURE(IUTEST_SKIP());
     IUTEST_ASSERT_NO_FAILURE(NoFatalFailureTest_Subroutine());
     IUTEST_ASSERT_NO_FAILURE({ IUTEST_SUCCEED(); });
 }
@@ -74,7 +69,6 @@ IUTEST(NoFailureTest, Expect)
 {
     IUTEST_EXPECT_NO_FAILURE(;);
     IUTEST_EXPECT_NO_FAILURE(IUTEST_SUCCEED());
-    IUTEST_EXPECT_NO_FAILURE(IUTEST_SKIP());
     IUTEST_EXPECT_NO_FAILURE(NoFatalFailureTest_Subroutine());
     IUTEST_EXPECT_NO_FAILURE({ IUTEST_SUCCEED(); });
 }
@@ -83,7 +77,6 @@ IUTEST(NoFailureTest, Inform)
 {
     IUTEST_INFORM_NO_FAILURE(;);
     IUTEST_INFORM_NO_FAILURE(IUTEST_SUCCEED());
-    IUTEST_INFORM_NO_FAILURE(IUTEST_SKIP());
     IUTEST_INFORM_NO_FAILURE(NoFatalFailureTest_Subroutine());
     IUTEST_INFORM_NO_FAILURE({ IUTEST_SUCCEED(); });
 }
@@ -92,7 +85,6 @@ IUTEST(NoFailureTest, Assume)
 {
     IUTEST_ASSUME_NO_FAILURE(;);
     IUTEST_ASSUME_NO_FAILURE(IUTEST_SUCCEED());
-    IUTEST_ASSUME_NO_FAILURE(IUTEST_SKIP());
     IUTEST_ASSUME_NO_FAILURE(NoFatalFailureTest_Subroutine());
     IUTEST_ASSUME_NO_FAILURE({ IUTEST_SUCCEED(); });
 }
